@@ -8,8 +8,8 @@ import argparse
 
 import zmq
 from zmq.utils.jsonapi import jsonmod as json
+from zmq.eventloop import ioloop, zmqstream
 
-from circus._zmq import ioloop, zmqstream
 from circus import logger, __version__
 from circus.client import make_message, cast_message
 from circus.util import (debuglog, to_bool, resolve_name, close_on_exec,
