@@ -1,10 +1,12 @@
 import os
 import json
 import tempfile
+import time
+
+from zmq.eventloop import ioloop
 
 from circus.stats.collector import SocketStatsCollector
 from circus.tests.support import TestCircus
-from circus._zmq import ioloop
 from circus.stats.streamer import StatsStreamer
 from circus import util
 from circus import client
@@ -75,19 +77,19 @@ class TestStatsStreamer(TestCircus):
 
         # events
         def _events():
-            msg = 'one.spawn', json.dumps({'process_pid': 187})
+            msg = 'one.spawn.two', json.dumps({'process_pid': 187})
             for i in range(5):
                 streamer.handle_recv(msg)
 
-        events = ioloop.DelayedCallback(_events, 500, loop)
-        events.start()
+        deadline = time.time() + 0.5
+        loop.add_timeout(deadline, _events)
 
         def _stop():
             self._collector.stop()
             streamer.stop()
 
-        stopper = ioloop.DelayedCallback(_stop, 500, loop)
-        stopper.start()
+        deadline = time.time() + 0.5
+        loop.add_timeout(deadline, _stop)
         streamer.start()
 
         # let's see what we got
