@@ -5,6 +5,7 @@ import signal
 import time
 import sys
 from random import randint
+import site
 
 from psutil import NoSuchProcess
 from zmq.utils.jsonapi import jsonmod as json
@@ -18,6 +19,7 @@ from circus.util import parse_env_dict, resolve_name
 
 
 class Watcher(object):
+
     """
     Class managing a list of processes for a given command.
 
@@ -161,6 +163,7 @@ class Watcher(object):
     - **close_child_stderr**: If True, closes the stderr after the fork.
       default: False.
     """
+
     def __init__(self, name, cmd, args=None, numprocesses=1, warmup_delay=0.,
                  working_dir=None, shell=False, uid=None, max_retry=5,
                  gid=None, send_hup=False, env=None, stopped=True,
@@ -200,8 +203,7 @@ class Watcher(object):
         self.max_age = int(max_age)
         self.max_age_variance = int(max_age_variance)
         self.ignore_hook_failure = ['before_stop', 'after_stop']
-        self.hooks = {}
-        self._resolve_hooks(hooks)
+
         self.respawn = respawn
         self.autostart = autostart
         self.close_child_stdout = close_child_stdout
@@ -247,10 +249,20 @@ class Watcher(object):
         if self.virtualenv:
             util.load_virtualenv(self)
 
+        # load directories in PYTHONPATH if provided
+        # so if a hook is there, it can be loaded
+        if self.env is not None and 'PYTHONPATH' in self.env:
+            for path in self.env['PYTHONPATH'].split(os.pathsep):
+                if path in sys.path:
+                    continue
+                site.addsitedir(path)
+
         self.rlimits = rlimits
         self.send_hup = send_hup
         self.sockets = self.evpub_socket = None
         self.arbiter = None
+        self.hooks = {}
+        self._resolve_hooks(hooks)
 
     def _reload_hook(self, key, hook, ignore_error):
         hook_name = key.split('.')[-1]
@@ -476,11 +488,12 @@ class Watcher(object):
                                     env=self.env)
         self._process_counter += 1
         nb_tries = 0
-        pipe_stdout = self.stdout_redirector is not None
-        pipe_stderr = self.stderr_redirector is not None
 
         while nb_tries < self.max_retry or self.max_retry == -1:
             process = None
+            pipe_stdout = self.stdout_redirector is not None
+            pipe_stderr = self.stderr_redirector is not None
+
             try:
                 process = Process(self._process_counter, cmd,
                                   args=self.args, working_dir=self.working_dir,
